@@ -22,7 +22,7 @@ COMMAND = const.COMMAND
 CMD = const.CMD
 
 IMG_ID = 'img-xxxxxx'
-INS_TYPE = 'ecs.s3.large'
+INS_TYPE = 'ecs.sn1ne.large'
 
 VERSION = const.VERSION
 
@@ -79,17 +79,19 @@ class Cli:
 
         1. %s config     # show configurations
         2. %s set -r cn-qingdao -o oss://my-bucket/bcscli/ -l zh_CN
-        3. %s set -i %s -t %s ''' % (COMMAND, CMD, CMD,CMD ,IMG_ID, INS_TYPE),
+        3. %s set -i %s -t %s
+        4. %s set --vpc_cidr_block 192.168.0.0/16''' % (COMMAND, CMD, CMD,CMD ,IMG_ID, INS_TYPE, CMD),
                              func=config.all)
         cmd_config.option('-r,--region [region]', MSG['config']['option']['region'])
         cmd_config.option('-o,--osspath [osspath]', MSG['config']['option']['osspath'] )
         cmd_config.option('-l,--locale [locale]', MSG['config']['option']['locale'])
         cmd_config.option('-i,--image [imageId]', MSG['config']['option']['image'])
-        cmd_config.option('-t,--type [instanceType]', MSG['config']['option']['type'])
+        cmd_config.option('-t,--type [instance_type]', MSG['config']['option']['type'])
         #cmd_config.option('-c,--cluster [clusterId]', MSG['config']['option']['cluster'])
         cmd_config.option('-s,--ssl [ssl]', MSG['config']['option']['ssl'], visible=IS_GOD)
         cmd_config.option('-v,--version [version]', MSG['config']['option']['version'], visible=IS_GOD)
         cmd_config.option('-u,--qsubuser [qsubuser]', MSG['config']['option']['qsubuser'], visible=IS_GOD)
+        cmd_config.option('--vpc_cidr_block [vpc_cidr_block]', MSG['config']['option']['vpc_cidr_block'])
         cmd_config.option('-g,--god [god]', MSG['config']['option']['god'], visible=IS_GOD)
         self.program.action(cmd_config)
 
@@ -231,6 +233,17 @@ class Cli:
 
         ######################
 
+
+        # recreate cluster instance
+        cmd_recreate_cluster_instance = cli_clusters.recreate_cluster_instance()
+        self.program.action(cmd_recreate_cluster_instance)
+
+        # delete cluster instance
+        cmd_delete_cluster_instance = cli_clusters.delete_cluster_instance()
+        self.program.action(cmd_delete_cluster_instance)
+
+        #################
+
         cmd_create_app = cli_apps.create()
         self.program.action(cmd_create_app)
 
