@@ -162,10 +162,10 @@ def __get_json():
                 'notification_events': "消息通知的事件,可以用'%s e'查看。" % CMD,
                 'notification_topic': "消息通知的Topic名称,可以在mns创建。",
                 'notification_endpoint': "消息通知的Endpoint, 可以在mns控制台查看。",
-                'mount': """可选,读写模式挂载NAS配置或者只读方式挂载OSS, 格式: <nas_path|oss_path>:<dir_path>[,<nas_path2|oss_path2>:<dir_path2>...],
-                                             如: nas://path/to/mount/:/home/admin/nasdir/ 表示将NAS路径挂载到本地目录。
+                'mount': """可选,读写模式挂载NAS配置或者只读方式挂载OSS, 格式: <nas_path|oss_path>:<dir_path>[:write_support],多个以英文逗号隔开。
+                                             如: nas://path/to/mount/:/home/admin/nasdir/:false 表示将NAS路径挂载到本地目录,write_support为false。
                                              使用NAS挂载还需配置nas_access_group和nas_file_system。
-                                             如: oss://path/to/mount/:/home/admin/nasdir/ 表示将OSS路径挂载到本地目录,
+                                             如: oss://path/to/mount/:/home/admin/nasdir/:true 表示将OSS路径挂载到本地目录,write_support为true。
                                              也支持直接挂载文件, 如:oss://path/to/mount/a.txt:/home/admin/nasdir/a.txt。""",
                 'nas_access_group': 'NAS 权限组',
                 'nas_file_system': 'NAS 文件系统',
@@ -191,15 +191,29 @@ def __get_json():
                 'env': "可选,设置环境变量, 格式: <k>:<v>[,<k2>:<v2>...]",
                 'spot_price_limit': '可选, resource_type为Spot时有效(单位为元,可以为小数). 设置为0表示使用系统自动出价(但不会超过按量付费价格)',
                 'user_data': "可选, 用户数据, k:v 对,多个逗号隔开, 格式: k:v,k2:v2",
-                'mount': """可选,读写模式挂载NAS配置, 格式: <nas_path>:<dir_path>[,<nas_path2>:<dir_path2>...],
-        如: nas://path/to/mount:/home/admin/nasdir 表示将NAS路径挂载到本地目录。
-        使用NAS挂载还需配置nas_access_group和nas_file_system""",
+                'mount': """可选,读写模式挂载NAS配置或者只读方式挂载OSS, 格式: <nas_path|oss_path>:<dir_path>[:write_support],多个以英文逗号隔开。
+                                            如: nas://path/to/mount/:/home/admin/nasdir/:false 表示将NAS路径挂载到本地目录,write_support为false。
+                                            使用NAS挂载还需配置nas_access_group和nas_file_system。
+                                            如: oss://path/to/mount/:/home/admin/nasdir/:true 表示将OSS路径挂载到本地目录,write_support为true。
+                                            也支持直接挂载文件, 如:oss://path/to/mount/a.txt:/home/admin/nasdir/a.txt。""",
                 'image': "可选, imageId, 更多信息输入 %s i 查看" % CMD,
                 'type': "可选, instanceType, 更多信息输入 %s t 查看" % CMD,
                 'show_json': '只显示cluster json不创建'
             }
 
         },
+        "recreate_cluster_instance": {
+            'description': '重新创建集群实例',
+            'option': {
+                'yes': "可选, 不要询问直接重新创建",
+            }
+        },
+        "delete_cluster_instance": {
+            'description': '删除集群实例',
+            'option': {
+                'yes': "可选, 不要询问直接删除",
+            }
+        },
         "create_app": {
            'description': '创建 App',
             'option': {
@@ -324,16 +338,14 @@ def __get_json():
                 'force': "可选,当instance失败时job不失败, 默认:当instance失败时job也失败",
                 'auto_release': "可选,当job运行成功(state=='Finished')后自动被释放(删除)掉",
                 'env': "可选,设置环境变量, 格式: <k>:<v>[,<k2>:<v2>...]",
-                'read_mount': """可选,只读模式挂载配置, 格式: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
-                                             挂载目录例子: oss://bucket/key/:/home/admin/ossdir/ 表示将oss的路径挂载为本地目录,
-                                             挂载文件例子: oss://bucket/key1:/home/admin/key1 表示将oss的文件挂载为本地文件""",
+                'read_mount': """可选,行为和 --mount 一样, 请参看 mount 选项""",
                 'write_mount': """可选,可写模式挂载配置(任务结束后写到本地目录的文件会被上传到相应的oss_path下),
                                              格式: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
                                              如: oss://bucket/key/:/home/admin/ossdir/ 表示将oss的路径挂载到本地目录""",
-                'mount': """可选,读写模式挂载NAS配置或者只读方式挂载OSS, 格式: <nas_path|oss_path>:<dir_path>[,<nas_path2|oss_path2>:<dir_path2>...],
-                                             如: nas://path/to/mount/:/home/admin/nasdir/ 表示将NAS路径挂载到本地目录。
+                'mount': """可选,读写模式挂载NAS配置或者只读方式挂载OSS, 格式: <nas_path|oss_path>:<dir_path>[:write_support],多个以英文逗号隔开。
+                                             如: nas://path/to/mount/:/home/admin/nasdir/:false 表示将NAS路径挂载到本地目录,write_support为false。
                                              使用NAS挂载还需配置nas_access_group和nas_file_system。
-                                             如: oss://path/to/mount/:/home/admin/nasdir/ 表示将OSS路径挂载到本地目录,
+                                             如: oss://path/to/mount/:/home/admin/nasdir/:true 表示将OSS路径挂载到本地目录,write_support为true。
                                              也支持直接挂载文件, 如:oss://path/to/mount/a.txt:/home/admin/nasdir/a.txt。""",
                 'log_mapping': """可选,日志映射配置(程序运行时写到本地目录的文件会被上传到相应的oss_path下),
                                              格式: <oss_path>:<file_path>[,<oss_path2>:<file_path2>...],
