@@ -81,6 +81,45 @@ def update_cluster(cluster_id, clusterDesc):
 
 
 
+
+#######################
+
+def list_cluster_instances(cluster_id, group_name):
+    client = _get_client()
+    arr = __list_clusters_instances(client, cluster_id, group_name, marker='', maxItemCount=100)
+    return {'Items': arr, 'Marker': ''}
+
+
+def __list_clusters_instances(client, cluster_id, group_name, marker='', maxItemCount=100):
+    t = []
+
+    result = client.list_cluster_instances(cluster_id, group_name, marker, maxItemCount)
+    if result.Items:
+        t = t + __items2list(result.Items)
+
+    if result.NextMarker and result.NextMarker != '':
+        arr = __list_clusters_instances(client, cluster_id, group_name, result.NextMarker, maxItemCount)
+        t = t + arr
+    return t
+
+def delete_cluster_instance(cluster_id, group_name, instance_id):
+    client = _get_client()
+    return client.delete_cluster_instance(cluster_id, group_name, instance_id)
+
+def recreate_cluster_instance(cluster_id, group_name, instance_id):
+    client = _get_client()
+    return client.recreate_cluster_instance(cluster_id, group_name, instance_id)
+
+
+
+
+
+
+
+###################
+
+
+
 def list_jobs():
     client = _get_client()
     arr = __list_jobs(client)
