@@ -6,12 +6,14 @@ from terminal import green, white, red, yellow, cyan
 import os
 import re
 
+def sub_desc(s):
+    return s[0:20]+'...' if len(s)>20 else s
 
 def get_cluster_state(state):
     s = state.lower() if state else state
     if s=='active':
         return green(state)
-    elif s=='deleting':
+    elif s=='deleting' or s=='error':
         return red(state)
     else:
         return white(state)
@@ -53,16 +55,17 @@ def filter_list(arr, filters):
        2. {NumRunningInstance: {'>': 1}}
        3. {JobName: {'like':'jobName1'}}
        4. {JobName: {'startswith':'qsub-'}}
+       5. {JobName: {'startswith':['qsub-user1-','qsub-user2-']}}
     '''
-    t = []
+    t = arr
 
     for k in filters:
 
         if isinstance(filters[k], STRING):
-            t = [item for item in arr if filters[k].lower() == item.get(k).lower()]
+            t = [item for item in t if filters[k].lower() == item.get(k).lower()]
         if isinstance(filters[k], (list,tuple)):
             alist = [ x.lower() for x in filters[k]]
-            t = [item for item in arr if (item.get(k) != None and item.get(k).lower() in alist )]
+            t = [item for item in t if (item.get(k) != None and item.get(k).lower() in alist )]
         if isinstance(filters[k], dict):
 
             startswith = filters[k].get('startswith')
@@ -74,14 +77,21 @@ def filter_list(arr, filters):
             lt = filters[k].get('<')
 
             if startswith != None:
-                startswith = startswith.lower()
-                t = [item for item in arr if item.get(k).lower().startswith(startswith)]
+
+                startswith = [startswith] if isinstance(startswith, STRING) else startswith
+                startswith = map(lambda x:x.lower(), startswith)
+                t2=[]
+                for item in arr:
+                    for ss in startswith:
+                        if item.get(k).lower().startswith(ss):
+                            t2.append(item)
+                t=t2
 
             elif like != None:
                 like = like.lower()
-                t = [item for item in arr if like in item.get(k).lower()]
+                t = [item for item in t if like in item.get(k).lower()]
             elif (gt != None or lt != None):
-                t = [item for item in arr
+                t = [item for item in t
                      if (gt == None or gt != None and item.get(k) > gt) or (lt == None or lt != None and item.get(k) < lt)]
             else:
                 t = arr
@@ -106,7 +116,11 @@ def sub(s, l=10):
 
 def format_date_in_arr(arr, cols):
     t=[]
-    for m in arr:
+
+    for n in arr:
+        m = {}
+        for k in n:
+            m[k]=n[k]
         if 'StartTime' in cols and 'EndTime' in cols:
             m['Elapsed'] = calc_elapse(m.get('StartTime'), m.get('EndTime'))
 
@@ -231,3 +245,43 @@ def get_job_id(hexId):
     s = (hex(int(v))[2:-1]).upper()
     return 'job-%s%s' % ('0'*(32-len(s)), s)
 
+
+
+def trans_app_inputs_params(params):
+    items = params.split(',')
+    m = {}
+    for item in items:
+        # {name}:{type}:{localpath}:{desc}:{defaultValue}
+        arr = item.split(':',4)
+
+        m[arr[0]] = {
+            'Type': arr[1] if len(arr)>1 and arr[1] else 'String',
+            'LocalPath': arr[2] if len(arr) > 2 else '',
+            'Description': arr[3] if len(arr) > 3 else '',
+            'Default': arr[4] if len(arr) > 4 else '',
+        }
+    return m
+
+
+def trans_app_outputs_params(params):
+    items = params.split(',')
+    m = {}
+    for item in items:
+        # {name}:{type}:{localpath}:{desc}
+        arr = item.split(':',4)
+
+        m[arr[0]] = {
+            'Type': arr[1] if len(arr)>1 and arr[1] else 'String',
+            'LocalPath': arr[2] if len(arr) > 2 else '',
+            'Description': arr[3] if len(arr) > 3 else ''
+        }
+    return m
+
+def trans_app_config_item(item, fn=None):
+    arr = item.split(':')
+    m = {
+        'Default': (fn(arr[0]) if fn else arr[0]) if len(arr) > 0 else '',
+        'Overwritable': bool(arr[1]) if len(arr) > 1 else False,
+        'Description': arr[2] if len(arr) > 2 else '',
+    }
+    return m
\ No newline at end of file
